#
# spec file for package qgis
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qgis
Version:        2.18.15
Release:        0
Summary:        QGIS is a Geographic Information System (GIS)
License:        GPL-2.0
Group:          Productivity/Graphics/Visualization/Other
Url:            https://qgis.org/
Source:         https://qgis.org/downloads/%{name}-%{version}.tar.bz2
Source4:        https://qgis.org/downloads/%{name}-%{version}.tar.bz2.md5
Source1:        %{name}.desktop
Source2:        %{name}.rpmlintrc
Source3:        qgis_sample_data.zip
BuildRequires:  sqlite-devel >= 3.5
BuildRequires:  fdupes
# Fix TW dependencies
%if 0%{?suse_version} > 1325
BuildRequires:  python-wxWidgets > 3.0
BuildRequires:  libwx_gtk2u_qa-suse3 > 3.0
%else
BuildRequires:  python-wxWidgets
BuildRequires:  libwx_gtk2u_qa-2_8-0-stl
%endif
BuildRequires:  -post-build-checks
BuildRequires:  FastCGI-devel
BuildRequires:  bison >= 2.4
BuildRequires:  cmake >= 2.8.6
BuildRequires:  flex >= 2.5.6
BuildRequires:  gdal >= 1.4
BuildRequires:  grass >= 7
BuildRequires:  grass-devel
BuildRequires:  gsl >= 1.8
BuildRequires:  gsl-devel
BuildRequires:  libexpat-devel
BuildRequires:  libspatialindex-devel
BuildRequires:	libspatialite-devel
BuildRequires:  libspatialindex4
BuildRequires:  libqscintilla-devel
BuildRequires:  libspatialite-devel
BuildRequires:  python-devel >= 2.7
BuildRequires:  python-qt4-devel
BuildRequires:  python-sip-devel
BuildRequires:  libQtWebKit-devel
BuildRequires:  libgdal-devel >= 1.4.0
BuildRequires:  libgeos-devel >= 3.4
BuildRequires:  libproj-devel
BuildRequires:  libqca2-devel
BuildRequires:  libqt4-devel >= 4.8
BuildRequires:  libqt4-qt3support >= 4.8
BuildRequires:  postgresql-devel >= 8
BuildRequires:  qwt-devel >= 5
BuildRequires:  txt2tags
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       python-matplotlib
Requires:       python-qscintilla
Requires:       python-psycopg2
Requires:       python-requests
Requires:       python-gdal
Requires:       python-qt4
Requires:       python-qt4-utils
Requires:       python-sip
Requires:       python-xml
%if 0%{?suse_version} > 1325
Requires:       python-wxWidgets > 3.0
Requires:       libwx_gtk2u_qa-suse3 > 3.0
%else
Requires:       python-wxWidgets
Requires:       libwx_gtk2u_qa-2_8-0-stl
%endif
Requires:       libqca2
Requires:       qca
Requires:       python-Jinja2
Requires:       python-Pygments
Recommends:     apache2-mod_fcgid
Recommends:     libqca2-plugin-cyrus-sasl
Recommends:     libqca2-plugin-pkcs11
Recommends:     qca-sasl
Recommends:     gpsbabel
Recommends:     %{name}-sample-data
Obsoletes:      qgis2 qgis-master qgis-ltr
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%package devel
Summary:        Development Libraries for the QGIS
Group:          Development/Libraries/C and C++
Requires:       qgis = %{version}
Requires:       python-qt4-devel

%package plugin-grass
Summary:        GRASS Support Libraries for QGIS
Group:          Productivity/Graphics/Visualization/Other
Requires:       grass
Requires:       grass-docs
Requires:       qgis = %{version}

%package sample-data
Summary:        QGIS sample data
Group:          Productivity/Graphics/Visualization/Other

%define builddir build
%define sampledir sample-data

%description
QGIS is a user friendly Open Source Geographic Information System (GIS)
that runs on Linux, Unix, Mac OSX, and Windows. QGIS supports vector,
raster, OWS and database formats. QGIS is licensed under the GNU
General Public License. QGIS lets you browse and create map data on your
computer. It supports many common spatial data formats (e.g. ESRI ShapeFile,
geotiff). QGIS supports plugins to do things like display tracks from your GPS.

%description devel
Development packages for QGIS including the C header files.

%description plugin-grass
GRASS plugin for QGIS required to interface with GRASS system.

%description sample-data
QGIS sample data with free raster, vector, gps files and a GRASS location from Alaska area.

%prep
%setup -q
#Fix shebang 
#sed -i "s,^#!/usr/bin/env python$,#!/usr/bin/python," ./src/plugins/grass/modules/*.py

%build
export CFLAGS="%{optflags}"
export QTDIR=/usr
export PATH=$PATH:$QTDIR/bin

%ifarch x86_64 aarch64 ppc64 ppc64le
%define lib lib64
%else
%define lib lib
%endif

cd ..
mkdir temp
cd temp

cmake -Wno-dev %{intsq} \
      -D CMAKE_INSTALL_PREFIX=%{_prefix} \
      -D CMAKE_BUILD_TYPE="Release" \
      -D QGIS_LIB_SUBDIR=%{lib} \
      -D WITH_BINDINGS=TRUE \
      -D WITH_QSPATIALITE=TRUE \
      -D WITH_PYSPATIALITE=TRUE \
      -D WITH_SERVER=TRUE \
      -D WITH_SERVER_PLUGINS=TRUE \
      -D POSTGRES_LIBRARY=%{_libdir}/libpq.so \
      -D QGIS_PLUGIN_SUBDIR=%{lib}/qgis \
      -D QGIS_MANUAL_SUBDIR=share/man \
      -D QWT_INCLUDE_DIR=/usr/include/qwt5 \
      -D CMAKE_SKIP_RPATH=OFF \
	../%{name}-%{version}/

#echo "for 'make' run first:"
export QTDIR=%{_prefix}
#echo "export PATH=$PATH:$QTDIR/bin"
export PATH=$PATH:$QTDIR/bin
#use multi-core & let that optionnal if jobs is specified as meta
make %{?jobs:-j%{jobs}}

%install
cd ../temp
%makeinstall

mkdir -p %{buildroot}%{_datadir}/applications
cp %{SOURCE1} %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/pixmaps
ln -s ../qgis/images/icons/qgis-icon.png %{buildroot}/%{_datadir}/pixmaps/qgis.png

# Do not update .desktop files
%suse_update_desktop_file -n %{name}

# Install sample data
pushd %{buildroot}%{_datadir}/qgis
unzip %{SOURCE3}
mv qgis_sample_data %{sampledir}
find %{sampledir} -depth \( -name .tmp -o -name .bash\* -o -name \*~ \) -exec rm -r {} \;
popd

%fdupes -s %{buildroot}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/*
%{_libdir}/libqgispython.s*
#%%{_libdir}/libqgis_*s*
%{_libdir}/libqgis*s*
%{_libdir}/qgis/
%{_libdir}/qt4/plugins/sqldrivers/libqsqlspatialite.so
%{_mandir}/man1/*
%{_datadir}/qgis/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/qgis.png
%{_prefix}/lib/qgis/qgis_help
%{_prefix}/lib/qgis/crssync
%exclude %{_prefix}/lib/debug/
%exclude %{_libdir}/libqgisgrass.so
%exclude %{_libdir}/libqgisgrass.so.*
%exclude %{_libdir}/qgis/libgrass*
#%%doc BUGS COPYING README

%files devel
%defattr(-,root,root)
%{_prefix}/include/qgis/*

%files plugin-grass
%defattr(644,root,root)
%{_libdir}/qgis/libgrass*
#%%{_libdir}/libqgisgrass.so
#%%{_libdir}/libqgisgrass.so.*
%defattr(755,root,root)
%{_prefix}/lib/qgis/grass/bin/qgis.g.browser7
%{_prefix}/lib/qgis/grass/modules/qgis.*

%files sample-data
%defattr(644,root,root)
%{_datadir}/qgis/%{sampledir}

%post plugin-grass -p /sbin/ldconfig

%postun plugin-grass -p /sbin/ldconfig

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%changelog
